@@ -6,8 +6,8 @@ pub struct Empty<T, E>(E, PhantomData<T>);
 impl<T, E> ListFn for Empty<T, E> {
     type Item = T;
     type End = Self;
-    fn list(self) -> List<Self> {
-        List::End(self)
+    fn state(self) -> ListState<Self> {
+        ListState::End(self)
     }
 }
 
@@ -19,5 +19,7 @@ impl<T, E> Empty<T, E> {
 
 impl<T, E> ResultFn for Empty<T, E> {
     type Result = E;
-    fn result(self) -> E { self.0 }
-}
\ No newline at end of file
+    fn result(self) -> E {
+        self.0
+    }
+}
